@@ -55,12 +55,12 @@ def envvars():
     return EnvVars(user, rsa_key, dsa_key)
 
 
-def shell_command(command, combine=False, decodebytes=False):
+def shell_command(command, combine=False, decodebytes=True):
     """Run a command in the shell on localhost and return the output
 
     :param command: String containing the shell script to run
-    :param combine: Direct stderr to stdout (default = False)
-    :param decodebytes: Decode bytes objects to unicode strings (default = False)
+    :param combine: Direct stderr to stdout
+    :param decodebytes: Decode bytes objects to unicode strings
     :return: NamedTuple for (cmd, stdout, stderr) or (cmd, stdout)
     """
     if combine:
@@ -85,7 +85,11 @@ def shell_command(command, combine=False, decodebytes=False):
 
 
 def do_shell_script(command, combine=False):
-    """ Alias to shell_command.  Use that one!  This call will go away in sshreader v4.0
+    """ Alias to shell_command.
+
+    .. warning::
+
+        This call will be deprecated in v4.0
 
     :param command: String containing the shell script to run
     :param combine: Combine stderr and stdout in output
@@ -102,9 +106,9 @@ class SSH(object):
     :param username: SSH username
     :param password: SSH password
     :param keyfile: SSH keyfile (can be used instead of password)
-    :param port: SSH port (default = 22)
-    :param timeout: SSH connection timeout in seconds (default = 30)
-    :param connect: Initiate the connect (default = True)
+    :param port: SSH port
+    :param timeout: SSH connection timeout in seconds
+    :param connect: Initiate the connect
     :return: SSH connection object
     :raises: SSHException
     """
@@ -133,13 +137,13 @@ class SSH(object):
     def __exit__(self, exc_type, exc_val, exc_tb):
         self.close()
 
-    def ssh_command(self, command, timeout=30, combine=False, decodebytes=False):
+    def ssh_command(self, command, timeout=30, combine=False, decodebytes=True):
         """Run a command over an ssh connection
 
         :param command: The command to run
         :param timeout: Timeout for the command
         :param combine: Combine stderr and stdout
-        :param decodebytes: Decode bytes objects to unicode strings (default = False)
+        :param decodebytes: Decode bytes objects to unicode strings
         :return: Namedtuple of (cmd, stdout, stderr, return_code) or (cmd, stdout, return_code)
         :raises: SSHException
         """
